jQuery UI Resizable - Constrain resize area

#container { width: 300px; height: 300px; } #container h3 { text-align: center; margin: 0; margin-bottom: 10px; } #resizable { background-position: top left; width: 150px; height: 150px; } #resizable, #container { padding: 0.5em; }

### Containment

### Resizable

Define the boundaries of the resizable area. Use the `containment` option to specify a parent DOM element or a jQuery selector, like 'document.'